==> tamejs-0.3.6.tgz: package/test/cases/28.out.js <==
var tame = require('tamejs').runtime;
var __tame_fn_0 = function (__tame_k) {
    "use strict" ;
    
    var assert = require ( "assert" ) ;
    
    var side_effect = 0 ;
    function do_side_effect () {
        side_effect = 1 ;
        return 10;
    }
    ;
    function foo () {
        var __tame_this = this;
        var __tame_fn_1 = function (__tame_k) {
            var __tame_fn_2 = function (__tame_k) {
                var __tame_defers = new tame.Defers (__tame_k);
                var __tame_fn_3 = function (__tame_k) {
                    setTimeout (
                    __tame_defers.defer ()
                    , 2 ) ;
                    tame.callChain([__tame_k]);
                };
                __tame_fn_3(tame.end);
                __tame_defers._fulfill();
            };
            do_side_effect ( );
            tame.callChain([__tame_fn_2, tame.end, __tame_k]);
        };
        tame.callChain([__tame_fn_1, __tame_k]);
    }
    ;
    
    var tmp ;
    
    exports [ "test that return value side effects happen" ] = {
    
    run :
    function  (cb) {
        var __tame_this = this;
        var __tame_fn_8 = function (__tame_k) {
            foo ( ) ;
            var __tame_fn_4 = function (__tame_k) {
                var __tame_fn_5 = function (__tame_k) {
                    var __tame_defers = new tame.Defers (__tame_k);
                    var __tame_fn_6 = function (__tame_k) {
                        setTimeout (
                        __tame_defers.defer ()
                        , 5 ) ;
                        tame.callChain([__tame_k]);
                    };
                    __tame_fn_6(tame.end);
                    __tame_defers._fulfill();
                };
                var __tame_fn_7 = function (__tame_k) {
                    cb ( ) ;
                    tame.callChain([__tame_k]);
                };
                tame.callChain([__tame_fn_5, __tame_fn_7, __tame_k]);
            };
            tame.callChain([__tame_fn_4, __tame_k]);
        };
        tame.callChain([__tame_fn_8, __tame_k]);
    }
    ,
    
    check :
    function  () {
        assert . equal ( side_effect , 1 ) ;
    }
    } ;
    tame.callChain([__tame_k]);
};
__tame_fn_0 (tame.end);

==> tamejs-0.3.7.tgz: package/test/cases/28.out.js <==
var tame = require('tamejs').runtime;
var __tame_fn_0 = function (__tame_k) {
    "use strict" ;
    
    var assert = require ( "assert" ) ;
    
    var side_effect = 0 ;
    function do_side_effect () {
        side_effect = 1 ;
        return 10;
    }
    ;
    function foo () {
        var __tame_this = this;
        var __tame_fn_1 = function (__tame_k) {
            var __tame_fn_2 = function (__tame_k) {
                var __tame_defers = new tame.Defers (__tame_k);
                var __tame_fn_3 = function (__tame_k) {
                    setTimeout (
                    __tame_defers.defer ()
                    , 2 ) ;
                    tame.callChain([__tame_k]);
                };
                __tame_fn_3(tame.end);
                __tame_defers._fulfill();
            };
            var __tame_fn_4 = function (__tame_k) {
                    do_side_effect ( );
                    tame.callChain([tame.end, __tame_k]);
            };
            tame.callChain([__tame_fn_2, __tame_fn_4, __tame_k]);
        };
        tame.callChain([__tame_fn_1, __tame_k]);
    }
    ;
    
    var tmp ;
    
    exports [ "test that return value side effects happen" ] = {
    
    run :
    function  (cb) {
        var __tame_this = this;
        var __tame_fn_9 = function (__tame_k) {
            foo ( ) ;
            var __tame_fn_5 = function (__tame_k) {
                var __tame_fn_6 = function (__tame_k) {
                    var __tame_defers = new tame.Defers (__tame_k);
                    var __tame_fn_7 = function (__tame_k) {
                        setTimeout (
                        __tame_defers.defer ()
                        , 5 ) ;
                        tame.callChain([__tame_k]);
                    };
                    __tame_fn_7(tame.end);
                    __tame_defers._fulfill();
                };
                var __tame_fn_8 = function (__tame_k) {
                    cb ( ) ;
                    tame.callChain([__tame_k]);
                };
                tame.callChain([__tame_fn_6, __tame_fn_8, __tame_k]);
            };
            tame.callChain([__tame_fn_5, __tame_k]);
        };
        tame.callChain([__tame_fn_9, __tame_k]);
    }
    ,
    
    check :
    function  () {
        assert . equal ( side_effect , 1 ) ;
    }
    } ;
    tame.callChain([__tame_k]);
};
__tame_fn_0 (tame.end);
